@@ -24,26 +24,24 @@
     # some people use it to bombard users with 
     # messages using 
     
-    packageStartupMessage( "\n" )
-    packageStartupMessage( "Rmetrics Package fOptions" ) 
-    packageStartupMessage( "Pricing and Evaluating Basic Options" )
-    packageStartupMessage( "Copyright (C) 2005-2014 Rmetrics Association Zurich" )  
-    packageStartupMessage( "Educational Software for Financial Engineering and Computational Science" ) 
-    packageStartupMessage( "Rmetrics is free software and comes with ABSOLUTELY NO WARRANTY." ) 
-    packageStartupMessage( "https://www.rmetrics.org --- Mail to: info@rmetrics.org" ) 
+    # packageStartupMessage( "\n" )
+    # packageStartupMessage( "Rmetrics Package fMultivar" ) 
+    # packageStartupMessage( "Analysing and Modeling Multivariate Financial Return Distributions" )
+    # packageStartupMessage( "Copyright (C) 2005-2014 Rmetrics Association Zurich" )  
+    # packageStartupMessage( "Educational Software for Financial Engineering and Computational Science" ) 
+    # packageStartupMessage( "Rmetrics is free software and comes with ABSOLUTELY NO WARRANTY." ) 
+    # packageStartupMessage( "https://www.rmetrics.org --- Mail to: info@rmetrics.org" )
   }
 
 ###############################################################################
 
 .onLoad <- 
   function(libname, pkgname) 
-{
-  .setfOptionsEnv(.runif.halton.seed = list())
-  .setfOptionsEnv(.rnorm.halton.seed = list())
-  .setfOptionsEnv(.runif.sobol.seed = list())
-  .setfOptionsEnv(.rnorm.sobol.seed = list())
-}
+  {
+    .setfOptionsEnv(.runif.halton.seed = list())
+    .setfOptionsEnv(.rnorm.halton.seed = list())
+    .setfOptionsEnv(.runif.sobol.seed = list())
+    .setfOptionsEnv(.rnorm.sobol.seed = list())
+  }
 
 ###############################################################################
-
-
